// Programme : Afficheur ST7735
// Carte : Arduino Uno
// Fichier : ST7735.ino

// Bibliothèques
#include <Adafruit_GFX.h> // Bibliothèques graphiques
#include <Adafruit_SPITFT_Macros.h>
#include <Adafruit_SPITFT.h>
#include <gfxfont.h>
#include <Adafruit_ST7735.h> // Bibliothèques spécifiques aux matériels
#include <Adafruit_ST7789.h>
#include <Adafruit_ST77xx.h>
#include <SPI.h> // Communication sur un Bus SPI

// Configuration des broches du micro pour commander un afficheur à ST7735
// Pour la sélection du ST7735, vous pouvez utiliser 2 ou 3 broches
// Ces broches fonctionneront également pour le shield TFT de 1,8 "
#define TFT_CS 10 // Cheap Select (Sélection du composant)
#define TFT_RST 9 // Peut être connectéé à la broche de remise à zéro (RST) de l'Arduino \
                  // dans ce cas, définissez cette broche #define sur 0!
#define TFT_DC 8  // Sélection d'une Données / Commandes

// Interface SPI matérielle
// (pour une UNO  SPI CLK = 13 and SPI MOSI = 11)et la broche 10 doit être
// une sortie. C'est beaucoup plus rapide - également nécessaire si vous voulez
// une carte micro SD
Adafruit_ST7735 tft = Adafruit_ST7735(TFT_CS, TFT_DC, TFT_RST); // Constructeur

const PROGMEM byte sprite[] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff}; // Bitmap 1

void setup()
{
    Serial.begin(9600);
    Serial.print("Hello! ST7735 TFT Test");

    // Initialisation d'un afficheur TFT 1.8 "
    tft.initR(INITR_BLACKTAB);    // initialise un circuit ST7735R
    tft.fillScreen(ST7735_BLACK); // Efface l'écran

    // Affichage d'un pixel en vert
    tft.drawPixel(10, 20, ST7735_GREEN);
    delay(100);

    // Affichage d'une ligne en diagonale sur l'écran
    tft.drawLine(0, 0, 128, 160, ST7735_BLUE);
    delay(100);

    // Affichage d'une croix au centre de l'écran
    tft.drawFastVLine(tft.width() / 2, 0, tft.height(), ST7735_WHITE);
    tft.drawFastHLine(0, tft.height() / 2, tft.width(), ST7735_WHITE);
    delay(100);

    // Dessin d'un rectangle plein
    tft.drawRect(40, 85, 20, 30, ST7735_RED);
    delay(100);
    tft.fillRect(40, 85, 20, 30, ST7735_RED);
    delay(100);

    // Dessin d'un cercle plein
    tft.drawCircle(84, 100, 10, ST7735_GREEN);
    delay(100);
    tft.fillCircle(84, 100, 10, ST7735_GREEN);
    delay(100);

    // Dessin d'un rectangle plein aux bords arrondis
    tft.drawRoundRect(40, 45, 20, 30, 5, ST7735_YELLOW);
    delay(100);
    tft.fillRoundRect(40, 45, 20, 30, 5, ST7735_YELLOW);
    delay(100);

    // Dessin d'un triangle rectangle plein
    tft.drawTriangle(100, 45, 70, 45, 70, 75, ST7735_CYAN);
    delay(100);
    tft.fillTriangle(100, 45, 70, 45, 70, 75, ST7735_CYAN);
    delay(100);

    // Affichage du caractère '@'
    tft.drawChar(110, 140, '@', ST7735_YELLOW, ST7735_BLACK, 2);
    delay(100);

    // Affichage de la largeur et de la hauteur de l'écran
    uint16_t largeur = tft.width();
    uint16_t hauteur = tft.height();
    tft.setCursor(5, 5);
    tft.setTextColor(ST7735_YELLOW);
    tft.print("largeur = ");
    tft.print(largeur);
    tft.print("px");
    tft.setCursor(5, 15);
    tft.setTextColor(ST7735_BLACK, ST7735_WHITE);
    tft.print("hauteur = ");
    tft.print(hauteur);
    tft.print("px");
    delay(100);
    tft.setCursor(5, 140);
    tft.setTextColor(ST7735_YELLOW, ST7735_BLACK);
    tft.setTextSize(2);
    tft.print("Arduino");
    delay(10000);
    tft.fillScreen(ST7735_BLACK);
    // Rotation 90° sens horaire
    tft.setRotation(1);
    tft.setCursor(5, 15);
    tft.setTextColor(ST7735_WHITE, ST7735_BLACK);
    tft.print("Rotation -90");
    delay(10000);

    // Bitmaps
    tft.drawBitmap(40, 40, sprite, 16, 10, ST7735_GREEN, ST7735_RED); // Pixel à 1 en vert, pixel à 0 en rouge
}

void loop()
{
    delay(10);
}